@@ -10,6 +10,10 @@ use open IO => 'utf8', ':std';
 use Hash::Util qw(lock_keys);
 use Data::Dumper;
 
+use Exporter 'import';
+our @EXPORT;
+our @EXPORT_OK;
+
 my($mod, $argv);
 
 sub initialize {
@@ -125,20 +129,27 @@ sub io_filter (&@) {
     exit 0;
 }
 
+push @EXPORT_OK, 'io_filter';
+
 sub set {
-    my %opt = @_;
+    my  %opt = @_;
+    our @waitpids;
     for my $io (qw(PREFORK STDIN STDOUT STDERR)) {
 	my $filter = delete $opt{$io} // next;
+	my $pid;
 	if ($filter =~ s/^&//) {
 	    if ($filter !~ /::/) {
 		$filter = join '::', __PACKAGE__, $filter;
 	    }
 	    use Getopt::EX::Func qw(parse_func);
 	    my $func = parse_func($filter);
-	    io_filter { $func->call() } $io => 1;
+	    $pid = io_filter { $func->call() } $io => 1;
 	}
 	else {
-	    io_filter { exec $filter or die "exec: $!\n" } $io => 1;
+	    $pid = io_filter { exec $filter or die "exec: $!\n" } $io => 1;
+	}
+	if ($io eq 'STDOUT' or $io eq 'STDERR') {
+	    push @waitpids, $pid;
 	}
     }
     %opt and die "Unknown parameter: " . Dumper \%opt;
@@ -168,6 +179,8 @@ sub unctrl {
     }
 }
 
+push @EXPORT_OK, 'unctrl';
+
 =item B<unctrl>()
 
 Visualize control characters.
@@ -176,41 +189,42 @@ Visualize control characters.
 
 ######################################################################
 
-my %control = (
-    nul => [ 's', "\000", "\x{2400}" ], # ␀ SYMBOL FOR NULL
-    soh => [ 's', "\001", "\x{2401}" ], # ␁ SYMBOL FOR START OF HEADING
-    stx => [ 's', "\002", "\x{2402}" ], # ␂ SYMBOL FOR START OF TEXT
-    etx => [ 's', "\003", "\x{2403}" ], # ␃ SYMBOL FOR END OF TEXT
-    eot => [ 's', "\004", "\x{2404}" ], # ␄ SYMBOL FOR END OF TRANSMISSION
-    enq => [ 's', "\005", "\x{2405}" ], # ␅ SYMBOL FOR ENQUIRY
-    ack => [ 's', "\006", "\x{2406}" ], # ␆ SYMBOL FOR ACKNOWLEDGE
-    bel => [ 's', "\007", "\x{2407}" ], # ␇ SYMBOL FOR BELL
-    bs  => [ 's', "\010", "\x{2408}" ], # ␈ SYMBOL FOR BACKSPACE
-    ht  => [ 's', "\011", "\x{2409}" ], # ␉ SYMBOL FOR HORIZONTAL TABULATION
-    nl  => [  '', "\012", "\x{240A}" ], # ␊ SYMBOL FOR LINE FEED
-    vt  => [ 's', "\013", "\x{240B}" ], # ␋ SYMBOL FOR VERTICAL TABULATION
-    np  => [ 's', "\014", "\x{240C}" ], # ␌ SYMBOL FOR FORM FEED
-    cr  => [ 's', "\015", "\x{240D}" ], # ␍ SYMBOL FOR CARRIAGE RETURN
-    so  => [ 's', "\016", "\x{240E}" ], # ␎ SYMBOL FOR SHIFT OUT
-    si  => [ 's', "\017", "\x{240F}" ], # ␏ SYMBOL FOR SHIFT IN
-    dle => [ 's', "\020", "\x{2410}" ], # ␐ SYMBOL FOR DATA LINK ESCAPE
-    dc1 => [ 's', "\021", "\x{2411}" ], # ␑ SYMBOL FOR DEVICE CONTROL ONE
-    dc2 => [ 's', "\022", "\x{2412}" ], # ␒ SYMBOL FOR DEVICE CONTROL TWO
-    dc3 => [ 's', "\023", "\x{2413}" ], # ␓ SYMBOL FOR DEVICE CONTROL THREE
-    dc4 => [ 's', "\024", "\x{2414}" ], # ␔ SYMBOL FOR DEVICE CONTROL FOUR
-    nak => [ 's', "\025", "\x{2415}" ], # ␕ SYMBOL FOR NEGATIVE ACKNOWLEDGE
-    syn => [ 's', "\026", "\x{2416}" ], # ␖ SYMBOL FOR SYNCHRONOUS IDLE
-    etb => [ 's', "\027", "\x{2417}" ], # ␗ SYMBOL FOR END OF TRANSMISSION BLOCK
-    can => [ 's', "\030", "\x{2418}" ], # ␘ SYMBOL FOR CANCEL
-    em  => [ 's', "\031", "\x{2419}" ], # ␙ SYMBOL FOR END OF MEDIUM
-    sub => [ 's', "\032", "\x{241A}" ], # ␚ SYMBOL FOR SUBSTITUTE
-    esc => [  '', "\033", "\x{241B}" ], # ␛ SYMBOL FOR ESCAPE
-    fs  => [ 's', "\034", "\x{241C}" ], # ␜ SYMBOL FOR FILE SEPARATOR
-    gs  => [ 's', "\035", "\x{241D}" ], # ␝ SYMBOL FOR GROUP SEPARATOR
-    rs  => [ 's', "\036", "\x{241E}" ], # ␞ SYMBOL FOR RECORD SEPARATOR
-    us  => [ 's', "\037", "\x{241F}" ], # ␟ SYMBOL FOR UNIT SEPARATOR
-    sp  => [ 's', "\040", "\x{2420}" ], # ␠ SYMBOL FOR SPACE
-    del => [ 's', "\177", "\x{2421}" ], # ␡ SYMBOL FOR DELETE
+my %control  = (
+    nul  => [ 's', "\000", "\x{2400}" ], # ␀ SYMBOL FOR NULL
+    soh  => [ 's', "\001", "\x{2401}" ], # ␁ SYMBOL FOR START OF HEADING
+    stx  => [ 's', "\002", "\x{2402}" ], # ␂ SYMBOL FOR START OF TEXT
+    etx  => [ 's', "\003", "\x{2403}" ], # ␃ SYMBOL FOR END OF TEXT
+    eot  => [ 's', "\004", "\x{2404}" ], # ␄ SYMBOL FOR END OF TRANSMISSION
+    enq  => [ 's', "\005", "\x{2405}" ], # ␅ SYMBOL FOR ENQUIRY
+    ack  => [ 's', "\006", "\x{2406}" ], # ␆ SYMBOL FOR ACKNOWLEDGE
+    bel  => [ 's', "\007", "\x{2407}" ], # ␇ SYMBOL FOR BELL
+    bs   => [ 's', "\010", "\x{2408}" ], # ␈ SYMBOL FOR BACKSPACE
+    ht   => [ 's', "\011", "\x{2409}" ], # ␉ SYMBOL FOR HORIZONTAL TABULATION
+    nl   => [  '', "\012", "\x{240A}" ], # ␊ SYMBOL FOR LINE FEED
+    vt   => [ 's', "\013", "\x{240B}" ], # ␋ SYMBOL FOR VERTICAL TABULATION
+    np   => [ 's', "\014", "\x{240C}" ], # ␌ SYMBOL FOR FORM FEED
+    cr   => [ 's', "\015", "\x{240D}" ], # ␍ SYMBOL FOR CARRIAGE RETURN
+    so   => [ 's', "\016", "\x{240E}" ], # ␎ SYMBOL FOR SHIFT OUT
+    si   => [ 's', "\017", "\x{240F}" ], # ␏ SYMBOL FOR SHIFT IN
+    dle  => [ 's', "\020", "\x{2410}" ], # ␐ SYMBOL FOR DATA LINK ESCAPE
+    dc1  => [ 's', "\021", "\x{2411}" ], # ␑ SYMBOL FOR DEVICE CONTROL ONE
+    dc2  => [ 's', "\022", "\x{2412}" ], # ␒ SYMBOL FOR DEVICE CONTROL TWO
+    dc3  => [ 's', "\023", "\x{2413}" ], # ␓ SYMBOL FOR DEVICE CONTROL THREE
+    dc4  => [ 's', "\024", "\x{2414}" ], # ␔ SYMBOL FOR DEVICE CONTROL FOUR
+    nak  => [ 's', "\025", "\x{2415}" ], # ␕ SYMBOL FOR NEGATIVE ACKNOWLEDGE
+    syn  => [ 's', "\026", "\x{2416}" ], # ␖ SYMBOL FOR SYNCHRONOUS IDLE
+    etb  => [ 's', "\027", "\x{2417}" ], # ␗ SYMBOL FOR END OF TRANSMISSION BLOCK
+    can  => [ 's', "\030", "\x{2418}" ], # ␘ SYMBOL FOR CANCEL
+    em   => [ 's', "\031", "\x{2419}" ], # ␙ SYMBOL FOR END OF MEDIUM
+    sub  => [ 's', "\032", "\x{241A}" ], # ␚ SYMBOL FOR SUBSTITUTE
+    esc  => [  '', "\033", "\x{241B}" ], # ␛ SYMBOL FOR ESCAPE
+    fs   => [ 's', "\034", "\x{241C}" ], # ␜ SYMBOL FOR FILE SEPARATOR
+    gs   => [ 's', "\035", "\x{241D}" ], # ␝ SYMBOL FOR GROUP SEPARATOR
+    rs   => [ 's', "\036", "\x{241E}" ], # ␞ SYMBOL FOR RECORD SEPARATOR
+    us   => [ 's', "\037", "\x{241F}" ], # ␟ SYMBOL FOR UNIT SEPARATOR
+    sp   => [ 's', "\040", "\x{2420}" ], # ␠ SYMBOL FOR SPACE
+    del  => [ 's', "\177", "\x{2421}" ], # ␡ SYMBOL FOR DELETE
+    nbsp => [ 's', "\240", "\x{2423}" ], # ␣ OPEN BOX
 );
 
 use List::Util qw(pairmap);
@@ -225,12 +239,14 @@ sub visible {
     my %opt = @_;
     my %flag = pairmap { $a => $b->[0] } %control;
     lock_keys %flag;
-    if (my $all = delete $opt{all}) {
+    if (defined(my $all = delete $opt{all})) {
 	$flag{$_} = $all for keys %flag;
     }
-    my($tabstyle, $s_char, $c_char) = ('bar', '', '');
-    if (exists $opt{tabstyle}) {
-	$tabstyle = delete $opt{tabstyle};
+    my($s_char, $c_char) = ('', '');
+    for my $name (qw(tabstyle tabstop)) {
+	if (exists $opt{$name} and my $value = delete $opt{$name}) {
+	    Text::ANSI::Tabs->configure($name => $value);
+	}
     }
     %flag = (%flag, %opt);
     for my $name (keys %flag) {
@@ -238,17 +254,18 @@ sub visible {
 	elsif ($flag{$name})        { $s_char .= $char{$name} }
     }
     while (<>) {
-	if ($tabstyle) {
-	    $_ = ansi_expand($_, tabstyle => $tabstyle);
-	}
-	s/(?=(${keep_after}?))([$s_char]|(?#why?)(?!))/$symbol{$2}$1/g
+	$_ = ansi_expand($_);
+	s{(?=(${keep_after}?))([$s_char]|(?#bug?)(?!))}{$symbol{$2}$1}g
 	    if $s_char ne '';
-	s/(?=(${keep_after}?))([$c_char])/'^'.pack('c',ord($2)+64).$1/ge
-	    if $c_char ne '';
+	s{(?=(${keep_after}?))([$c_char]|(?#bug?)(?!))}{
+	    '^'.pack('c',ord($2)+64).$1
+	}ge if $c_char ne '';
 	print;
     }
 }
 
+push @EXPORT_OK, 'visible';
+
 =item B<visible>(I<name>=I<flag>)
 
 Make control and space characters visible.
@@ -264,16 +281,22 @@ visible representation.
 
 =item I<name>
 
-Name is C<tabstyle>, C<all>, or one of these: [ nul soh stx etx eot
-enq ack bel bs ht nl vt np cr so si dle dc1 dc2 dc3 dc4 nak syn etb
-can em sub esc fs gs rs us sp del ].
+Name is C<tabstop>, C<tabstyle>, C<all>, or one of these:
 
-If the name is C<all>, the value is set for all characters.  Default
-is equivalent to:
+    000 nul  001 soh  002 stx  003 etx  004 eot  005 enq  006 ack  007 bel
+    010 bs   011 ht   012 nl   013 vt   014 np   015 cr   016 so   017 si
+    020 dle  021 dc1  022 dc2  023 dc3  024 dc4  025 nak  026 syn  027 etb
+    030 can  031 em   032 sub  033 esc  034 fs   035 gs   036 rs   037 us
+    040 sp
+    240 nbsp
+
+If the name is C<all>, the value is set for all characters.
+Default is equivalent to:
 
     visible(tabstyle=bar,all=s,esc=0,nl=0)
 
-As for C<tabstyle>, use anything defined in L<Text::ANSI::Fold>.
+Tab width can be set by C<tabstop>.  As for C<tabstyle>, use anything
+defined in L<Text::ANSI::Fold>.
 
 =item I<flag>
 
@@ -291,6 +314,8 @@ sub rev_line {
     print reverse <STDIN>;
 }
 
+push @EXPORT_OK, 'rev_line';
+
 =item B<rev_line>()
 
 Reverse output.
@@ -301,11 +326,13 @@ Reverse output.
 
 sub rev_char {
     while (<>) {
-	print reverse /./g;
-	print "\n" if /\n\z/;
+	my $lb = s/(\R)\z// ? $1 : '';
+	print reverse(/\X/g), $lb;
     }
 }
 
+push @EXPORT_OK, 'rev_char';
+
 =item B<rev_char>()
 
 Reverse characters in each line.
@@ -320,6 +347,8 @@ sub shuffle_line {
     print shuffle <>;
 }
 
+push @EXPORT_OK, 'shuffle';
+
 =item B<shuffle_line>()
 
 Shuffle lines.
@@ -328,6 +357,30 @@ Shuffle lines.
 
 ######################################################################
 
+use Time::HiRes qw(usleep);
+
+sub interval {
+    my %opt = @_;
+    $opt{time} //= 1;
+    my $sleep = $opt{time} > 0 ? $opt{time} * 1000000 : 0;
+    io_filter {
+	while (<>) {
+	    print;
+	    usleep $sleep;
+	}
+    } STDOUT => 1 if $sleep > 0;
+}
+
+push @EXPORT_OK, 'interval';
+
+=item B<interval>()
+
+Output each line at regular intervals of time.
+
+=cut
+
+######################################################################
+
 use Getopt::EX::Colormap qw(colorize);
 
 sub io_color {
@@ -343,6 +396,8 @@ sub io_color {
     ();
 }
 
+push @EXPORT_OK, 'io_color';
+
 =item B<io_color>( B<IO>=I<color> )
 
 Colorize text. B<IO> is either of C<STDOUT> or C<STDERR>.  Use comma
@@ -402,6 +457,8 @@ sub timestamp {
     }
 }
 
+push @EXPORT_OK, 'timestamp';
+
 =item B<timestamp>( [ format=I<strftime_format> ] )
 
 Put timestamp on each line of output.
@@ -419,6 +476,8 @@ sub gunzip { exec "gunzip -c" }
 
 sub gzip   { exec "gzip -c" }
 
+push @EXPORT_OK, 'gunzip', 'gzip';
+
 =item B<gunzip>()
 
 Gunzip standard input.
